==> kubernetes-client-4.12.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/extensions/v1beta1/NetworkPolicyOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.extensions.v1beta1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.extensions.DoneableNetworkPolicy;
import io.fabric8.kubernetes.api.model.extensions.NetworkPolicy;
import io.fabric8.kubernetes.api.model.extensions.NetworkPolicyList;
import io.fabric8.kubernetes.api.model.extensions.DoneableNetworkPolicy;

import java.util.Map;
import java.util.TreeMap;


public class NetworkPolicyOperationsImpl extends HasMetadataOperation<NetworkPolicy, NetworkPolicyList, DoneableNetworkPolicy, Resource<NetworkPolicy, DoneableNetworkPolicy>> {

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public NetworkPolicyOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("extensions")
    .withApiGroupVersion("v1beta1")
    .withPlural("networkpolicies"));
    this.type = NetworkPolicy.class;
    this.listType = NetworkPolicyList.class;
    this.doneableType = DoneableNetworkPolicy.class;
  }

  public NetworkPolicyOperationsImpl newInstance(OperationContext context) {
    return new NetworkPolicyOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.4.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/extensions/v1beta1/NetworkPolicyOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.extensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.extensions.NetworkPolicy;
import io.fabric8.kubernetes.api.model.extensions.NetworkPolicyBuilder;
import io.fabric8.kubernetes.api.model.extensions.NetworkPolicyList;

import java.util.Map;
import java.util.TreeMap;


public class NetworkPolicyOperationsImpl extends HasMetadataOperation<NetworkPolicy, NetworkPolicyList, Resource<NetworkPolicy>> {

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public NetworkPolicyOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("extensions")
    .withApiGroupVersion("v1beta1")
    .withPlural("networkpolicies"));
    this.type = NetworkPolicy.class;
    this.listType = NetworkPolicyList.class;
  }

  public NetworkPolicyOperationsImpl newInstance(OperationContext context) {
    return new NetworkPolicyOperationsImpl(context);
  }

  @Override
  public NetworkPolicy edit(Visitor... visitors) {
    return patch(new NetworkPolicyBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
